@@ -20,22 +20,24 @@ import (
 	"fmt"
 	"io"
 
+	monv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
 	configv1 "github.com/openshift/api/config/v1"
 	v1 "k8s.io/api/core/v1"
 	k8syaml "k8s.io/apimachinery/pkg/util/yaml"
 )
 
 type Config struct {
-	Images                   *Images                   `json:"-"`
-	PrometheusOperatorConfig *PrometheusOperatorConfig `json:"prometheusOperator"`
-	PrometheusK8sConfig      *PrometheusK8sConfig      `json:"prometheusK8s"`
-	AlertmanagerMainConfig   *AlertmanagerMainConfig   `json:"alertmanagerMain"`
-	KubeStateMetricsConfig   *KubeStateMetricsConfig   `json:"kubeStateMetrics"`
-	GrafanaConfig            *GrafanaConfig            `json:"grafana"`
-	EtcdConfig               *EtcdConfig               `json:"-"`
-	HTTPConfig               *HTTPConfig               `json:"http"`
-	TelemeterClientConfig    *TelemeterClientConfig    `json:"telemeterClient"`
-	K8sPrometheusAdapter     *K8sPrometheusAdapter     `json:"k8sPrometheusAdapter"`
+	Images                   *Images                      `json:"-"`
+	PrometheusOperatorConfig *PrometheusOperatorConfig    `json:"prometheusOperator"`
+	PrometheusK8sConfig      *PrometheusK8sConfig         `json:"prometheusK8s"`
+	AlertmanagerMainConfig   *AlertmanagerMainConfig      `json:"alertmanagerMain"`
+	KubeStateMetricsConfig   *KubeStateMetricsConfig      `json:"kubeStateMetrics"`
+	OpenShiftMetricsConfig   *OpenShiftStateMetricsConfig `json:"openshiftStateMetrics"`
+	GrafanaConfig            *GrafanaConfig               `json:"grafana"`
+	EtcdConfig               *EtcdConfig                  `json:"-"`
+	HTTPConfig               *HTTPConfig                  `json:"http"`
+	TelemeterClientConfig    *TelemeterClientConfig       `json:"telemeterClient"`
+	K8sPrometheusAdapter     *K8sPrometheusAdapter        `json:"k8sPrometheusAdapter"`
 }
 
 type Images struct {
@@ -50,6 +52,7 @@ type Images struct {
 	OauthProxy               string
 	NodeExporter             string
 	KubeStateMetrics         string
+	OpenShiftStateMetrics    string
 	KubeRbacProxy            string
 	TelemeterClient          string
 }
@@ -62,19 +65,23 @@ type HTTPConfig struct {
 
 type PrometheusOperatorConfig struct {
 	NodeSelector map[string]string `json:"nodeSelector"`
+	Tolerations  []v1.Toleration   `json:"tolerations"`
 }
 
 type PrometheusK8sConfig struct {
 	Retention           string                    `json:"retention"`
 	NodeSelector        map[string]string         `json:"nodeSelector"`
+	Tolerations         []v1.Toleration           `json:"tolerations"`
 	Resources           *v1.ResourceRequirements  `json:"resources"`
 	ExternalLabels      map[string]string         `json:"externalLabels"`
 	VolumeClaimTemplate *v1.PersistentVolumeClaim `json:"volumeClaimTemplate"`
 	Hostport            string                    `json:"hostport"`
+	RemoteWrite         []monv1.RemoteWriteSpec   `json:"remoteWrite"`
 }
 
 type AlertmanagerMainConfig struct {
 	NodeSelector        map[string]string         `json:"nodeSelector"`
+	Tolerations         []v1.Toleration           `json:"tolerations"`
 	Resources           *v1.ResourceRequirements  `json:"resources"`
 	VolumeClaimTemplate *v1.PersistentVolumeClaim `json:"volumeClaimTemplate"`
 	Hostport            string                    `json:"hostport"`
@@ -82,15 +89,23 @@ type AlertmanagerMainConfig struct {
 
 type GrafanaConfig struct {
 	NodeSelector map[string]string `json:"nodeSelector"`
+	Tolerations  []v1.Toleration   `json:"tolerations"`
 	Hostport     string            `json:"hostport"`
 }
 
 type KubeStateMetricsConfig struct {
 	NodeSelector map[string]string `json:"nodeSelector"`
+	Tolerations  []v1.Toleration   `json:"tolerations"`
+}
+
+type OpenShiftStateMetricsConfig struct {
+	NodeSelector map[string]string `json:"nodeSelector"`
+	Tolerations  []v1.Toleration   `json:"tolerations"`
 }
 
 type K8sPrometheusAdapter struct {
 	NodeSelector map[string]string `json:"nodeSelector"`
+	Tolerations  []v1.Toleration   `json:"tolerations"`
 }
 
 type EtcdConfig struct {
@@ -112,6 +127,7 @@ type TelemeterClientConfig struct {
 	TelemeterServerURL string            `json:"telemeterServerURL"`
 	Token              string            `json:"token"`
 	NodeSelector       map[string]string `json:"nodeSelector"`
+	Tolerations        []v1.Toleration   `json:"tolerations"`
 }
 
 func (cfg *TelemeterClientConfig) IsEnabled() bool {
@@ -155,21 +171,18 @@ func (c *Config) applyDefaults() {
 	if c.PrometheusK8sConfig.Retention == "" {
 		c.PrometheusK8sConfig.Retention = "15d"
 	}
-	if c.PrometheusK8sConfig.Resources == nil {
-		c.PrometheusK8sConfig.Resources = &v1.ResourceRequirements{}
-	}
 	if c.AlertmanagerMainConfig == nil {
 		c.AlertmanagerMainConfig = &AlertmanagerMainConfig{}
 	}
-	if c.AlertmanagerMainConfig.Resources == nil {
-		c.AlertmanagerMainConfig.Resources = &v1.ResourceRequirements{}
-	}
 	if c.GrafanaConfig == nil {
 		c.GrafanaConfig = &GrafanaConfig{}
 	}
 	if c.KubeStateMetricsConfig == nil {
 		c.KubeStateMetricsConfig = &KubeStateMetricsConfig{}
 	}
+	if c.OpenShiftMetricsConfig == nil {
+		c.OpenShiftMetricsConfig = &OpenShiftStateMetricsConfig{}
+	}
 	if c.HTTPConfig == nil {
 		c.HTTPConfig = &HTTPConfig{}
 	}
@@ -198,6 +211,7 @@ func (c *Config) SetImages(images map[string]string) {
 	c.Images.TelemeterClient = images["telemeter-client"]
 	c.Images.PromLabelProxy = images["prom-label-proxy"]
 	c.Images.K8sPrometheusAdapter = images["k8s-prometheus-adapter"]
+	c.Images.OpenShiftStateMetrics = images["openshift-state-metrics"]
 }
 
 func (c *Config) LoadClusterID(load func() (*configv1.ClusterVersion, error)) error {
@@ -254,9 +268,9 @@ func (c *Config) LoadProxy(load func() (*configv1.Proxy, error)) error {
 		return fmt.Errorf("error loading proxy: %v", err)
 	}
 
-	c.HTTPConfig.HTTPProxy = p.Spec.HTTPProxy
-	c.HTTPConfig.HTTPSProxy = p.Spec.HTTPSProxy
-	c.HTTPConfig.NoProxy = p.Spec.NoProxy
+	c.HTTPConfig.HTTPProxy = p.Status.HTTPProxy
+	c.HTTPConfig.HTTPSProxy = p.Status.HTTPSProxy
+	c.HTTPConfig.NoProxy = p.Status.NoProxy
 
 	return nil
 }
